@@ -70,6 +70,9 @@ types: list[str] = [
     "AWS::Bedrock::GuardrailVersion",
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
+    "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
+    "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::CloudFormation::CustomResource",
     "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
@@ -86,6 +89,7 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionFunction",
     "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
@@ -99,6 +103,11 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudFront::TrustStore",
+    "AWS::CloudFront::VpcOrigin",
+    "AWS::CloudTrail::Dashboard",
+    "AWS::CloudTrail::EventDataStore",
+    "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
     "AWS::CloudWatch::Alarm",
     "AWS::CloudWatch::AnomalyDetector",
@@ -117,7 +126,9 @@ types: list[str] = [
     "AWS::Config::ConfigurationRecorder",
     "AWS::Config::ConformancePack",
     "AWS::Config::DeliveryChannel",
+    "AWS::Config::OrganizationConfigRule",
     "AWS::Config::OrganizationConformancePack",
+    "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
@@ -146,6 +157,7 @@ types: list[str] = [
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
     "AWS::EC2::CapacityReservation",
+    "AWS::EC2::CapacityReservationFleet",
     "AWS::EC2::CustomerGateway",
     "AWS::EC2::DHCPOptions",
     "AWS::EC2::EC2Fleet",
@@ -179,6 +191,11 @@ types: list[str] = [
     "AWS::EC2::PlacementGroup",
     "AWS::EC2::PrefixList",
     "AWS::EC2::Route",
+    "AWS::EC2::RouteServer",
+    "AWS::EC2::RouteServerAssociation",
+    "AWS::EC2::RouteServerEndpoint",
+    "AWS::EC2::RouteServerPeer",
+    "AWS::EC2::RouteServerPropagation",
     "AWS::EC2::RouteTable",
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
@@ -197,6 +214,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
     "AWS::EC2::TransitGatewayConnectPeer",
+    "AWS::EC2::TransitGatewayMeteringPolicy",
+    "AWS::EC2::TransitGatewayMeteringPolicyEntry",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -218,6 +237,7 @@ types: list[str] = [
     "AWS::EC2::VPCEndpointServicePermissions",
     "AWS::EC2::VPCGatewayAttachment",
     "AWS::EC2::VPCPeeringConnection",
+    "AWS::EC2::VPNConcentrator",
     "AWS::EC2::VPNConnection",
     "AWS::EC2::VPNConnectionRoute",
     "AWS::EC2::VPNGateway",
@@ -225,6 +245,7 @@ types: list[str] = [
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
+    "AWS::ECR::PullTimeUpdateExclusion",
     "AWS::ECR::RegistryPolicy",
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
@@ -233,6 +254,7 @@ types: list[str] = [
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
+    "AWS::ECS::ExpressGatewayService",
     "AWS::ECS::PrimaryTaskSet",
     "AWS::ECS::Service",
     "AWS::ECS::TaskDefinition",
@@ -242,6 +264,7 @@ types: list[str] = [
     "AWS::EFS::MountTarget",
     "AWS::EKS::AccessEntry",
     "AWS::EKS::Addon",
+    "AWS::EKS::Capability",
     "AWS::EKS::Cluster",
     "AWS::EKS::FargateProfile",
     "AWS::EKS::IdentityProviderConfig",
@@ -280,6 +303,7 @@ types: list[str] = [
     "AWS::Events::Rule",
     "AWS::FMS::NotificationChannel",
     "AWS::FMS::Policy",
+    "AWS::FMS::ResourceSet",
     "AWS::FSx::FileSystem",
     "AWS::FSx::Snapshot",
     "AWS::FSx::StorageVirtualMachine",
@@ -384,6 +408,7 @@ types: list[str] = [
     "AWS::MSK::Cluster",
     "AWS::MSK::ClusterPolicy",
     "AWS::MSK::Configuration",
+    "AWS::MSK::Replicator",
     "AWS::MSK::VpcConnection",
     "AWS::NetworkFirewall::Firewall",
     "AWS::NetworkFirewall::FirewallPolicy",
@@ -391,6 +416,20 @@ types: list[str] = [
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
     "AWS::NetworkFirewall::VpcEndpointAssociation",
+    "AWS::NetworkManager::ConnectAttachment",
+    "AWS::NetworkManager::ConnectPeer",
+    "AWS::NetworkManager::CoreNetwork",
+    "AWS::NetworkManager::CustomerGatewayAssociation",
+    "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::GlobalNetwork",
+    "AWS::NetworkManager::Link",
+    "AWS::NetworkManager::LinkAssociation",
+    "AWS::NetworkManager::Site",
+    "AWS::NetworkManager::SiteToSiteVpnAttachment",
+    "AWS::NetworkManager::TransitGatewayPeering",
+    "AWS::NetworkManager::TransitGatewayRegistration",
+    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
+    "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -583,7 +622,6 @@ cached: list[str] = [
     "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
-    "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
@@ -595,12 +633,16 @@ cached: list[str] = [
     "aws-backup-backupvault.json",
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
+    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
+    "aws-chatbot-microsoftteamschannelconfiguration.json",
+    "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloudformation-customresource.json",
     "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
@@ -615,6 +657,7 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectionfunction.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
@@ -628,7 +671,11 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
-    "aws-cloudtrail-trail.json",
+    "aws-cloudfront-truststore.json",
+    "aws-cloudfront-vpcorigin.json",
+    "aws-cloudtrail-dashboard.json",
+    "aws-cloudtrail-eventdatastore.json",
+    "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
     "aws-cloudwatch-compositealarm.json",
@@ -642,7 +689,9 @@ cached: list[str] = [
     "aws-config-configurationrecorder.json",
     "aws-config-conformancepack.json",
     "aws-config-deliverychannel.json",
+    "aws-config-organizationconfigrule.json",
     "aws-config-organizationconformancepack.json",
+    "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
@@ -668,6 +717,7 @@ cached: list[str] = [
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
+    "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
@@ -699,6 +749,11 @@ cached: list[str] = [
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
+    "aws-ec2-routeserver.json",
+    "aws-ec2-routeserverassociation.json",
+    "aws-ec2-routeserverendpoint.json",
+    "aws-ec2-routeserverpeer.json",
+    "aws-ec2-routeserverpropagation.json",
     "aws-ec2-routetable.json",
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
@@ -717,6 +772,8 @@ cached: list[str] = [
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
     "aws-ec2-transitgatewayconnectpeer.json",
+    "aws-ec2-transitgatewaymeteringpolicy.json",
+    "aws-ec2-transitgatewaymeteringpolicyentry.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -734,16 +791,18 @@ cached: list[str] = [
     "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
-    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
+    "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconcentrator.json",
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
+    "aws-ecr-pulltimeupdateexclusion.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
@@ -752,6 +811,7 @@ cached: list[str] = [
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
+    "aws-ecs-expressgatewayservice.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
@@ -761,10 +821,10 @@ cached: list[str] = [
     "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
+    "aws-eks-capability.json",
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -795,6 +855,7 @@ cached: list[str] = [
     "aws-events-rule.json",
     "aws-fms-notificationchannel.json",
     "aws-fms-policy.json",
+    "aws-fms-resourceset.json",
     "aws-fsx-filesystem.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
@@ -841,7 +902,6 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -867,13 +927,9 @@ cached: list[str] = [
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
-    "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
-    "aws-lambda-version.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
@@ -885,9 +941,9 @@ cached: list[str] = [
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
     "aws-msk-batchscramsecret.json",
-    "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
+    "aws-msk-replicator.json",
     "aws-msk-vpcconnection.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
@@ -895,6 +951,20 @@ cached: list[str] = [
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
+    "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
+    "aws-networkmanager-corenetwork.json",
+    "aws-networkmanager-customergatewayassociation.json",
+    "aws-networkmanager-device.json",
+    "aws-networkmanager-globalnetwork.json",
+    "aws-networkmanager-link.json",
+    "aws-networkmanager-linkassociation.json",
+    "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
+    "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchservice-domain.json",
@@ -905,7 +975,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
@@ -941,6 +1010,7 @@ cached: list[str] = [
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
+    "aws-route53-healthcheck.json",
     "aws-route53-hostedzone.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
@@ -955,7 +1025,6 @@ cached: list[str] = [
     "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accesspoint.json",
-    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
@@ -1004,7 +1073,9 @@ cached: list[str] = [
     "aws-synthetics-canary.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
+    "aws-transfer-connector.json",
     "aws-transfer-profile.json",
+    "aws-transfer-server.json",
     "aws-transfer-user.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-policy.json",
@@ -1013,8 +1084,10 @@ cached: list[str] = [
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
+    "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
     "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
